quantizationtools.QuantizationJob
=================================

.. abjad-lineage:: abjad.tools.quantizationtools.QuantizationJob.QuantizationJob

.. autoclass:: abjad.tools.quantizationtools.QuantizationJob.QuantizationJob

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.quantizationtools.QuantizationJob.QuantizationJob.job_id
      ~abjad.tools.quantizationtools.QuantizationJob.QuantizationJob.q_event_proxies
      ~abjad.tools.quantizationtools.QuantizationJob.QuantizationJob.q_grids
      ~abjad.tools.quantizationtools.QuantizationJob.QuantizationJob.search_tree
      ~abjad.tools.quantizationtools.QuantizationJob.QuantizationJob.__call__
      ~abjad.tools.quantizationtools.QuantizationJob.QuantizationJob.__eq__
      ~abjad.tools.quantizationtools.QuantizationJob.QuantizationJob.__format__
      ~abjad.tools.quantizationtools.QuantizationJob.QuantizationJob.__ne__
      ~abjad.tools.quantizationtools.QuantizationJob.QuantizationJob.__repr__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.quantizationtools.QuantizationJob.QuantizationJob.job_id
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QuantizationJob.QuantizationJob.q_event_proxies
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QuantizationJob.QuantizationJob.q_grids
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QuantizationJob.QuantizationJob.search_tree
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.quantizationtools.QuantizationJob.QuantizationJob.__call__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QuantizationJob.QuantizationJob.__eq__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QuantizationJob.QuantizationJob.__format__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QuantizationJob.QuantizationJob.__ne__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QuantizationJob.QuantizationJob.__repr__
   :noindex:
